==> oci-java-sdk-tenantmanagercontrolplane-1.32.0-sources.jar: com/oracle/bmc/tenantmanagercontrolplane/RecipientInvitationAsync.java <==
/**
 * Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.tenantmanagercontrolplane;

import com.oracle.bmc.tenantmanagercontrolplane.requests.*;
import com.oracle.bmc.tenantmanagercontrolplane.responses.*;

/**
 * A description of the TenantManager API
 */
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200801")
public interface RecipientInvitationAsync extends AutoCloseable {

    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the serice.
     */
    void setEndpoint(String endpoint);

    /**
     * Gets the set endpoint for REST call (ex, https://www.example.com)
     */
    String getEndpoint();

    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * <p>
     * Note, this will call {@link #setEndpoint(String) setEndpoint} after resolving the endpoint.  If the service is not available in this region, however, an IllegalArgumentException will be raised.
     * @param region The region of the service.
     */
    void setRegion(com.oracle.bmc.Region region);

    /**
     * Sets the region to call (ex, 'us-phoenix-1').
     * <p>
     * Note, this will first try to map the region ID to a known Region and call
     * {@link #setRegion(Region) setRegion}.
     * <p>
     * If no known Region could be determined, it will create an endpoint based on the
     * default endpoint format ({@link com.oracle.bmc.Region#formatDefaultRegionEndpoint(Service, String)}
     * and then call {@link #setEndpoint(String) setEndpoint}.
     * @param regionId The public region ID.
     */
    void setRegion(String regionId);

    /**
     * Accepts a recipient invitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<AcceptRecipientInvitationResponse> acceptRecipientInvitation(
            AcceptRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            AcceptRecipientInvitationRequest, AcceptRecipientInvitationResponse>
                    handler);

    /**
     * Gets information about the recipient invitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<GetRecipientInvitationResponse> getRecipientInvitation(
            GetRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            GetRecipientInvitationRequest, GetRecipientInvitationResponse>
                    handler);

    /**
     * Ignores a recipient invitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<IgnoreRecipientInvitationResponse> ignoreRecipientInvitation(
            IgnoreRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            IgnoreRecipientInvitationRequest, IgnoreRecipientInvitationResponse>
                    handler);

    /**
     * Return a (paginated) list of recipient invitations.
     *
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<ListRecipientInvitationsResponse> listRecipientInvitations(
            ListRecipientInvitationsRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListRecipientInvitationsRequest, ListRecipientInvitationsResponse>
                    handler);

    /**
     * Updates the RecipientInvitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<UpdateRecipientInvitationResponse> updateRecipientInvitation(
            UpdateRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            UpdateRecipientInvitationRequest, UpdateRecipientInvitationResponse>
                    handler);
}

==> oci-java-sdk-tenantmanagercontrolplane-1.34.0-sources.jar: com/oracle/bmc/tenantmanagercontrolplane/RecipientInvitationAsync.java <==
/**
 * Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.tenantmanagercontrolplane;

import com.oracle.bmc.tenantmanagercontrolplane.requests.*;
import com.oracle.bmc.tenantmanagercontrolplane.responses.*;

/**
 * The Organizations API allows you to consolidate multiple OCI tenancies into an organization, and centrally manage your tenancies and its resources.
 */
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20200801")
public interface RecipientInvitationAsync extends AutoCloseable {

    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the serice.
     */
    void setEndpoint(String endpoint);

    /**
     * Gets the set endpoint for REST call (ex, https://www.example.com)
     */
    String getEndpoint();

    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * <p>
     * Note, this will call {@link #setEndpoint(String) setEndpoint} after resolving the endpoint.  If the service is not available in this region, however, an IllegalArgumentException will be raised.
     * @param region The region of the service.
     */
    void setRegion(com.oracle.bmc.Region region);

    /**
     * Sets the region to call (ex, 'us-phoenix-1').
     * <p>
     * Note, this will first try to map the region ID to a known Region and call
     * {@link #setRegion(Region) setRegion}.
     * <p>
     * If no known Region could be determined, it will create an endpoint based on the
     * default endpoint format ({@link com.oracle.bmc.Region#formatDefaultRegionEndpoint(Service, String)}
     * and then call {@link #setEndpoint(String) setEndpoint}.
     * @param regionId The public region ID.
     */
    void setRegion(String regionId);

    /**
     * Accepts a recipient invitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<AcceptRecipientInvitationResponse> acceptRecipientInvitation(
            AcceptRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            AcceptRecipientInvitationRequest, AcceptRecipientInvitationResponse>
                    handler);

    /**
     * Gets information about the recipient invitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<GetRecipientInvitationResponse> getRecipientInvitation(
            GetRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            GetRecipientInvitationRequest, GetRecipientInvitationResponse>
                    handler);

    /**
     * Ignores a recipient invitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<IgnoreRecipientInvitationResponse> ignoreRecipientInvitation(
            IgnoreRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            IgnoreRecipientInvitationRequest, IgnoreRecipientInvitationResponse>
                    handler);

    /**
     * Return a (paginated) list of recipient invitations.
     *
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<ListRecipientInvitationsResponse> listRecipientInvitations(
            ListRecipientInvitationsRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            ListRecipientInvitationsRequest, ListRecipientInvitationsResponse>
                    handler);

    /**
     * Updates the RecipientInvitation.
     *
     * @param request The request object containing the details to send
     * @param handler The request handler to invoke upon completion, may be null.
     * @return A Future that can be used to get the response if no AsyncHandler was
     *         provided. Note, if you provide an AsyncHandler and use the Future, some
     *         types of responses (like java.io.InputStream) may not be able to be read in
     *         both places as the underlying stream may only be consumed once.
     */
    java.util.concurrent.Future<UpdateRecipientInvitationResponse> updateRecipientInvitation(
            UpdateRecipientInvitationRequest request,
            com.oracle.bmc.responses.AsyncHandler<
                            UpdateRecipientInvitationRequest, UpdateRecipientInvitationResponse>
                    handler);
}
